diff --git a/x264.c b/x264.c
index c3b4f29..2e3b9e3 100644
--- a/x264.c
+++ b/x264.c
@@ -137,7 +137,7 @@ static void Help( x264_param_t *defaults, int b_longhelp )
         "Syntax: x264 [options] -o outfile infile [widthxheight]\n"
         "\n"
         "Infile can be raw YUV 4:2:0 (in which case resolution is required),\n"
-        "  or YUV4MPEG 4:2:0 (*.y4m),\n"
+        "  or YUV4MPEG 4:2:0 (*.y4m or --y4m-input specified),\n"
         "  or AVI or Avisynth if compiled with AVIS support (%s).\n"
         "Outfile type is selected by filename:\n"
         " .264 -> Raw bytestream\n"
@@ -340,6 +340,7 @@ static void Help( x264_param_t *defaults, int b_longhelp )
     H0( "      --seek <integer>        First frame to encode\n" );
     H0( "      --frames <integer>      Maximum number of frames to encode\n" );
     H0( "      --level <string>        Specify level (as defined by Annex A)\n" );
+    H0( "      --y4m-input             Treat input as yuv4mpeg\n" );
     H0( "\n" );
     H0( "  -v, --verbose               Print stats for each frame\n" );
     H0( "      --no-progress           Don't show the progress indicator while encoding\n" );
@@ -370,6 +371,7 @@ static void Help( x264_param_t *defaults, int b_longhelp )
 #define OPT_PRESET 265
 #define OPT_TUNE 266
 #define OPT_SLOWFIRSTPASS 267
+#define OPT_Y4M_INPUT 268
 
 static char short_options[] = "8A:B:b:f:hI:i:m:o:p:q:r:t:Vvw";
 static struct option long_options[] =
@@ -462,6 +464,7 @@ static struct option long_options[] =
     { "dump-yuv",    required_argument, NULL, 0 },
     { "sps-id",      required_argument, NULL, 0 },
     { "aud",               no_argument, NULL, 0 },
+    { "y4m-input",         no_argument, NULL, OPT_Y4M_INPUT },
     { "nr",          required_argument, NULL, 0 },
     { "cqm",         required_argument, NULL, 0 },
     { "cqmfile",     required_argument, NULL, 0 },
@@ -717,6 +720,9 @@ static int  Parse( int argc, char **argv,
             case OPT_SEEK:
                 opt->i_seek = atoi( optarg );
                 break;
+            case OPT_Y4M_INPUT:
+                b_y4m = 1;
+                break;
             case 'o':
                 if( !strncasecmp(optarg + strlen(optarg) - 4, ".mp4", 4) )
                 {
@@ -882,10 +888,12 @@ generic_option:
     psz = psz_filename + strlen(psz_filename) - 1;
     while( psz > psz_filename && *psz != '.' )
         psz--;
-    if( !strncasecmp( psz, ".avi", 4 ) || !strncasecmp( psz, ".avs", 4 ) )
-        b_avis = 1;
-    if( !strncasecmp( psz, ".y4m", 4 ) )
-        b_y4m = 1;
+    if( !b_y4m ) {
+        if( !strncasecmp( psz, ".avi", 4 ) || !strncasecmp( psz, ".avs", 4 ) )
+            b_avis = 1;
+        if( !strncasecmp( psz, ".y4m", 4 ) )
+            b_y4m = 1;
+    }
 
     if( !(b_avis || b_y4m) ) // raw yuv
     {
